import React from 'react';
import {
  PageContainer,
  ProForm,
  ProFormText,
  ProFormTextArea,
  ProTable,
} from '@ant-design/pro-components';
import { Button, Card, Modal, Popover } from 'antd';
import { EditBundle, useEdit } from '@/core/hooks/useEdit';
import { PlusOutlined } from '@ant-design/icons';

export type HeadLine = {
  id: number;
  title: string;
  content: string;
  createTime: string;
};

const Edit: React.FC<{ bundle: EditBundle }> = (props) => {
  const { bundle } = props;
  const [form] = ProForm.useForm<HeadLine>();

  return (
    <Modal
      open={bundle.open}
      title={bundle.id ? '编辑' : '新增'}
      onCancel={() => {
        bundle.close();
      }}
      onOk={() => {}}
    >
      <ProForm
        className={'pt-5 pb-1'}
        form={form}
        submitter={false}
        layout={'horizontal'}
        labelCol={{ span: 4 }}
        validateTrigger={false}
      >
        <ProFormText
          name="title"
          label="标题"
          rules={[
            {
              required: true,
              message: '请输入标题',
            },
            {
              min: 3,
              max: 20,
              message: '标题长度在3-20之间',
            },
          ]}
        />
        <ProFormTextArea
          name="content"
          label="内容"
          fieldProps={{
            style: { height: 200 },
            count: {
              max: 1024,
              show: true,
            },
          }}
          rules={[
            {
              required: true,
              message: '请输入内容',
            },
            {
              min: 10,
              max: 1024,
              message: '内容长度在10-100之间',
            },
          ]}
        />
      </ProForm>
    </Modal>
  );
};

const HeadLines: React.FC<{}> = (props) => {
  const edit = useEdit();

  return (
    <PageContainer>
      <Card>
        {edit.open && <Edit bundle={edit} />}
        <ProTable<HeadLine>
          rowKey="id"
          search={false}
          toolbar={{
            settings: [],
            actions: [
              <Button
                icon={<PlusOutlined />}
                type={'primary'}
                key={'add'}
                onClick={() => edit.create()}
              >
                新建
              </Button>,
            ],
          }}
          columns={[
            {
              title: 'ID',
              dataIndex: 'id',
            },
            {
              title: '标题',
              dataIndex: 'title',
            },
            {
              title: '内容',
              dataIndex: 'content',
              render: (_, record) => {
                return (
                  <Popover content={record.content}>
                    <a href="#">查看</a>
                  </Popover>
                );
              },
            },
            {
              title: '创建时间',
              valueType: 'date',
              dataIndex: 'createTime',
            },
          ]}
        ></ProTable>
      </Card>
    </PageContainer>
  );
};

export default HeadLines;
