import {ProForm, ProFormInstance, ProFormText} from '@ant-design/pro-components';
import {message} from 'antd';
import React, {useRef} from 'react';
import {getConfigGetApi, postConfigSaveApi} from "@/services/swagger/configAdmin";


type VestSettings = {
  dropDelayTime: number;
  dropCnt: number;
};

export default () => {
  const formRef = useRef<ProFormInstance>();
  return (
    <ProForm
      layout="horizontal"
      title="签到设置"
      formRef={formRef}
      submitter={{}}
      request={async () => {
        const res = await getConfigGetApi({"code": "platform.vest.drop"})
        if (res.success && res.data.content) {
          const result: VestSettings = JSON.parse(res.data.content)
          return result;
        }

        return {
          dropDelayTime: 0,
          dropCnt: 0,
        }
      }}
      onFinish={async (values) => {
        const result: VestSettings = {
          dropDelayTime: parseInt(values.dropDelayTime),
          dropCnt: parseInt(values.dropCnt),
        };
        console.log("value " + values);

        const res = await postConfigSaveApi({
          "type": "json",
          "code": "platform.vest.drop",
          "remark": "马甲掉落配置",
          "content": JSON.stringify(result)
        })

        if (res.success) {
          message.success('提交成功');
        } else {
          message.error(res.errorMessage)
        }
        return res.success;
      }}
    >

      <ProFormText name="dropDelayTime" width="md" label={`间隔时间`} addonAfter={"分钟"}/>
      <ProFormText name="dropCnt" width="md" label={`数量`}/>
    </ProForm>
  );
};
