import {ActionType, PageContainer, ProForm,  ProFormText, ProTable,} from '@ant-design/pro-components';
import {Button, Card, Modal} from 'antd';
import React, {useRef} from 'react';
import {AddOutline} from 'antd-mobile-icons';
import {EditBundle, useEdit} from '@/core/hooks/useEdit';
import { deleteFactionLevelRemoveApi, getFactionLevelDetailsApi, postFactionLevelSaveApi,getFactionLevelListApi } from '@/services/swagger/factionLevelAdmin';

const Edit: React.FC<{ bundle: EditBundle; onSuccess?: () => void }> = (props) => {
  const {bundle} = props;
  const [form] = ProForm.useForm<SectApi.UserLevelSaveQuery>();
  const [loading, setLoading] = React.useState(false);

  return (
    <Modal
      confirmLoading={loading}
      title={bundle.id ? '编辑宗门等级' : '添加宗门等级'}
      open={bundle.open}
      onOk={async () => {
        await form.validateFields();

        try {
          setLoading(true);

          await postFactionLevelSaveApi({
            id: bundle.id,
            ...form.getFieldsValue()
          });
        } finally {
          setLoading(false);
        }

        props.onSuccess?.();
        bundle.close();
      }}
      onCancel={() => {
        form.resetFields();
        bundle.close();
      }}
    >
      <ProForm
        className={'mt-5'}
        form={form}
        labelCol={{span: 4}}
        layout={'horizontal'}
        submitter={false}
        request={async () => {
          if (bundle.id !== undefined) {
            console.log(bundle.id, 'bundle');
            const res = await getFactionLevelDetailsApi({id: bundle.id});

            return {
              ...res.data
            }
          }

          return Promise.resolve({});
        }}
      >
        <ProFormText name="level" label={'等级'} rules={[{required: true, message: '请输入等级',}]} placeholder={'请输入等级'}></ProFormText>
        <ProFormText name="name" label={'名称'} rules={[{required: true, message: '请输入名称',}]} placeholder={'请输入名称'}></ProFormText>
      </ProForm>
    </Modal>
  );
};

const FactionLevel: React.FC = () => {
  const bundle = useEdit();
  const ref = useRef<ActionType>();

  return (
    <PageContainer content={''}>
      {bundle.open && <Edit bundle={bundle} onSuccess={() => ref.current?.reload()}></Edit>}
      <Card>
        <ProTable<SectApi.UserLevelVO>
          rowKey={'id'}

          request={async (params, ...rest) => {
            console.log(params, ...rest)

            const res = await getFactionLevelListApi();
            return {
              success: res.success,
              data: res.data,
            };
          }}
          columns={[
            {
              title: '等级',
              dataIndex: 'level',
              render:(text)=>{
                return text + '级'
              }
            },
            {
              title: '名称',
              dataIndex: 'name',
            },
            {
              title: '人数',
              dataIndex: 'userCnt',
            },
            {
              title: '操作',
              valueType: 'option',
              render: (_, record) => [
                <a key={'edit'} onClick={() => bundle.update(record.id as number)}>
                  编辑
                </a>,
                <a
                  key={'delete'}
                  onClick={async () => {
                    if(record.id) {
                      await deleteFactionLevelRemoveApi({id: record.id})
                      ref.current?.reload();
                    }
                  }}
                >
                  删除
                </a>,
              ],
            },
          ]
          }
          pagination={false}
          search={false}
          form={{
            ignoreRules: false,
          }}


          actionRef={ref}
          toolbar={{
            actions: [
              <Button icon={<AddOutline/>} key={'add'} type={'primary'} onClick={bundle.create}>
                添加
              </Button>,
            ],
            settings: [],
          }}

        ></ProTable>
      </Card>
    </PageContainer>
  );
};

export default FactionLevel;
